@@ -2,8 +2,9 @@
 import torch 
 import torch.nn as nn 
 from bert_seq2seq.tokenizer import load_chinese_base_vocab, Tokenizer
+from bert_seq2seq.basic_bert import BasicBert
 
-class BertRelationExtrac(nn.Module):
+class BertRelationExtrac(BasicBert):
     """
     """
     def __init__(self, word2ix, predicate_num, model_name="roberta"):
@@ -53,10 +54,9 @@ class BertRelationExtrac(nn.Module):
         ## 抽取subject的向量表征
         batch_size = output.shape[0]
         hidden_size = output.shape[-1]
-        start = torch.gather(output, index=subject_ids[:, :1].unsqueeze(1).expand((batch_size, 1, hidden_size)), dim=1)
-        end = torch.gather(output, index=subject_ids[:, 1: ].unsqueeze(1).expand((batch_size, 1, hidden_size)), dim=1)
-        subject = torch.cat((start, end), dim=-1)
-        return subject[:, 0]
+        start_end = torch.gather(output, index=subject_ids.unsqueeze(-1).expand((batch_size, 2, hidden_size)), dim=1)
+        subject = torch.cat((start_end[:, 0], start_end[:, 1]), dim=-1)
+        return subject
 
     def forward(self, text, subject_ids, position_enc=None, subject_labels=None, object_labels=None, use_layer_num=-1, device="cpu"):
         if use_layer_num != -1:
@@ -71,19 +71,24 @@ class BertRelationExtrac(nn.Module):
         enc_layers, _ = self.bert(text, 
                                     output_all_encoded_layers=True)
         squence_out = enc_layers[use_layer_num] 
+        sub_out = enc_layers[-1]
 
-        transform_out = self.layer_norm(squence_out)
-        subject_pred_out = self.subject_pred(transform_out)
+        subject_pred_out = self.subject_pred(squence_out)
 
         subject_pred_act = self.activation(subject_pred_out)
-        subject_vec = self.extrac_subject(squence_out, subject_ids)
-        object_layer_norm = self.layer_norm_cond([squence_out, subject_vec])
+
+        # subject_pred_act = subject_pred_act**2 
+
+        subject_vec = self.extrac_subject(sub_out, subject_ids)
+        object_layer_norm = self.layer_norm_cond([sub_out, subject_vec])
         object_pred_out = self.object_pred(object_layer_norm)
         object_pred_act = self.activation(object_pred_out)
+
+        # object_pred_act = object_pred_act**4
+
         batch_size, seq_len, target_size = object_pred_act.shape
 
         object_pred_act = object_pred_act.reshape((batch_size, seq_len, int(target_size/2), 2))
-        # print(object_pred_act.shape)
         predictions = object_pred_act
         if subject_labels is not None and object_labels is not None:
             ## 计算loss
@@ -94,26 +99,27 @@ class BertRelationExtrac(nn.Module):
         else :
             return predictions
 
-    def predict_subject(self, text, position_enc=None, use_layer_num=-1, device="cpu"):
+    def predict_subject(self, text,use_layer_num=-1, device="cpu"):
         if use_layer_num != -1:
             if use_layer_num < 0 or use_layer_num > 7:
                 # 越界
                 raise Exception("层数选择错误，因为bert base模型共8层，所以参数只只允许0 - 7， 默认为-1，取最后一层")
-        # 计算target mask
         text = text.to(device)
 
         self.target_mask = (text > 0).float()
         enc_layers, _ = self.bert(text, output_all_encoded_layers=True)
         squence_out = enc_layers[use_layer_num]
-
-        transform_out = self.layer_norm(squence_out)
-        subject_pred_out = self.subject_pred(transform_out)
-
+        sub_out = enc_layers[-1]
+        # transform_out = self.layer_norm(squence_out)
+        subject_pred_out = self.subject_pred(squence_out)
         subject_pred_act = self.activation(subject_pred_out)
 
+        # subject_pred_act = subject_pred_act**2
+
+        # subject_pred_act = (subject_pred_act > 0.5).long() 
         return subject_pred_act
 
-    def predict_object_predicate(self, text, subject_ids, position_enc=None, subject_labels=None, object_labels=None, use_layer_num=-1, device="cpu"):
+    def predict_object_predicate(self, text, subject_ids, use_layer_num=-1, device="cpu"):
         if use_layer_num != -1:
             if use_layer_num < 0 or use_layer_num > 7:
                 # 越界
@@ -122,17 +128,17 @@ class BertRelationExtrac(nn.Module):
         text = text.to(device)
         subject_ids = subject_ids.to(device)
 
-        self.target_mask = (text > 0).float()
         enc_layers, _ = self.bert(text, output_all_encoded_layers=True)
         squence_out = enc_layers[use_layer_num]
-
-        subject_vec = self.extrac_subject(squence_out, subject_ids)
-        object_layer_norm = self.layer_norm_cond([squence_out, subject_vec])
+        sub_out = enc_layers[-1]
+        subject_vec = self.extrac_subject(sub_out, subject_ids)
+        object_layer_norm = self.layer_norm_cond([sub_out, subject_vec])
         object_pred_out = self.object_pred(object_layer_norm)
         object_pred_act = self.activation(object_pred_out)
-        batch_size, seq_len, target_size = object_pred_act.shape
 
-        object_pred_act = object_pred_act.reshape((batch_size, seq_len, int(target_size/2), 2))
-        # print(object_pred_act.shape)
+        # object_pred_act = object_pred_act**4 
+
+        batch_size, seq_len, target_size = object_pred_act.shape
+        object_pred_act = object_pred_act.view((batch_size, seq_len, int(target_size/2), 2))
         predictions = object_pred_act
-        return predictions
+        return predictions
\ No newline at end of file
