@@ -2,8 +2,9 @@
 import torch 
 import torch.nn as nn 
 from bert_seq2seq.tokenizer import load_chinese_base_vocab, Tokenizer
+from bert_seq2seq.basic_bert import BasicBert
 
-class BertSeqLabeling(nn.Module):
+class BertSeqLabeling(BasicBert):
     """
     """
     def __init__(self, word2ix, target_size, model_name="roberta"):
@@ -26,7 +27,6 @@ class BertSeqLabeling(nn.Module):
         
         
         self.final_dense = nn.Linear(config.hidden_size, self.target_size)
-        # self.activation = nn.Sigmoid()
     
     def compute_loss(self, predictions, labels):
         """
@@ -44,14 +44,12 @@ class BertSeqLabeling(nn.Module):
             if use_layer_num < 0 or use_layer_num > 7:
                 # 越界
                 raise Exception("层数选择错误，因为bert base模型共8层，所以参数只只允许0 - 7， 默认为-1，取最后一层")
-        # 计算target mask
         self.target_mask = (text > 0).float()
         enc_layers, _ = self.bert(text, 
                                     output_all_encoded_layers=True)
         squence_out = enc_layers[use_layer_num] 
 
         transform_out = self.transform(squence_out)
-        # print(cls_token)
         predictions = self.final_dense(transform_out)
         if labels is not None:
             ## 计算loss
